<?php

/*
Plugin Name: WPFTS Add-on for Elementor
Description: This plugin forces Elementor to show WPFTS's Smart Excerpts instead of "native" WP excerpts. Works with Pro and Free Elementor.
Version: 1.0.0
Tested up to: 5.7.1
Author: Epsiloncool
Author URI: https://e-wm.org
License: GPL3
License URI: http://www.gnu.org/licenses/gpl-3.0.html
Text Domain: wpfts_lang
Domain Path: /languages/
*/

/**
 *  Copyright 2013-2021 Epsiloncool
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************
 *  I am thank you for the help by buying PRO version of this plugin 
 *  at https://fulltextsearch.org/ 
 *  It will keep me working further on this useful product.
 ******************************************************************************
 * 
 *  @copyright 2013-2021
 *  @license GPL v3
 *  @version 1.0.0
 *  @package Wordpress Fulltext Search Pro
 *  @author Epsiloncool <info@e-wm.org>
 */

/**
 * Explanations: The Elementor plugin renders the search results page in "non-loop" mode, as the result,
  * the in_the_loop() native WP method returns false and WPFTS's 'get_the_excerpt' hook handler does not work properly.
  *
  * The solution is to force SE Excerpts with the first 'get_the_excerpt' hook call (just before first search result item render).
 */
 
add_filter('get_the_excerpt', function($out)
{
	global $wpfts_core;
	
	if ($wpfts_core) {
		$wpfts_core->ForceSmartExcerpts(get_search_query(false));
	}
	
	return $out;
}, 2);

